==> mysocials-core_1.0-1.tar.gz: mysocials-core-1.0/src/datatypes/account.h <==
#ifndef ACCOUNT_H
#define ACCOUNT_H

#include <QObject>
#include <QDomDocument>
#include <QFile>
#include <QDebug>
#include <QDir>
#include <QMetaType>
#include <QtConcurrentRun>

#include "qtransport.h"
#include "friend.h"
#include "utils/utils.h"
#include "datatypes/message.h"

// the name of file which profile was stored
#define FILE_ACCOUNT_DATA "profile.xml"

// XML root node for profile
#define NODE_ACCOUNT_ROOT "profile"

// XML node for storing library name
#define NODE_ACCOUNT_LIBRARY "library"

// XML node for storing driver settings
#define NODE_ACCOUNT_SETTINGS "settings"

#define FILE_FRIENDS_DATA "friends.xml"

#define NODE_FRIENDS_ROOT "friendsList"

#define FILE_INBOX_DATA "/messages.xml"

#define FILE_OUTBOX_DATA "/messages.xml"

#define NODE_MESSAGES_ROOT "messageList"

/*
 * class for account information storage.
 */
class Account: public QObject
{
    Q_OBJECT

private:
    FriendList friends; // list of loaded friends.
    AlbumList albums; // list of my albums.
    MessageList inboxMessages; // list of inbox messages.
    MessageList outboxMessages; // list of outbox messages.
    QString settings; // account settings. Uses in driver.
    QString oldSettings; // old account settings. Used if user didn't work with application

    // user account data
    Friend profile;

    // true if first request is success, otherwise false
    bool isLibraryInit;

public:
    Account(QString libraryName);
    Account(QString libraryName, QString accountId);
    ~Account();

    QTransport *transport; // interface of used driver.

    bool ready(); // check status of Accont

    void saveAccount(); // store account settings.
    static Account* loadAccount(QString accountId); // load account from storage.

    // get friend list or load it from cache file.
    FriendList getFriendList();

    // set friend list and store it to cache file.
    void setFriendList(FriendList);

    QString accountId();

    QString serviceName();

    /**
     * @brief get list of my albums or load it from cache
     *
     * @return AlbumList list of my albums
    */
    AlbumList getAlbumList();

    /**
     * @brief set list of my albums and store it to cache file
     *
     * @param AlbumList
    */
    void setAlbumList(AlbumList);

    MessageList getInboxMessageList();

    void setInboxMessageList(MessageList);

    MessageList getOutboxMessageList();

    void setOutboxMessageList(MessageList);

    Friend getProfile(bool isNeedUpdate);

    void setProfile(Friend profile);
    /**
     * @brief setup proxy settings for current driver
     *
     * @param proxyHost proxy host name or QString() if proxy not use
     * @param proxyPort proxy port number or 0 if proxy not use
    */
    void setProxy(QString proxyHost, int proxyPort);

    // checks that it is a first request
    bool isFirstRequest;

    // true if first request is success, otherwise false
    bool isNetworkEnabled;

private slots:
    void gotSettings(QString accountId, QString settings);
};

typedef QList<Account *> AccountList;

Q_DECLARE_METATYPE(Account *)

#endif // ACCOUNT_H

==> mysocials-core_1.1-1.tar.gz: mysocials-core-1.1/src/datatypes/account.h <==
#ifndef ACCOUNT_H
#define ACCOUNT_H

#include <QObject>
#include <QDomDocument>
#include <QFile>
#include <QDebug>
#include <QDir>
#include <QMetaType>
#include <QtConcurrentRun>

#include "qtransport.h"
#include "friend.h"
#include "utils/utils.h"
#include "datatypes/message.h"

// the name of file which profile was stored
#define FILE_ACCOUNT_DATA "profile.xml"

// XML root node for profile
#define NODE_ACCOUNT_ROOT "profile"

// XML node for storing library name
#define NODE_ACCOUNT_LIBRARY "library"

// XML node for storing driver settings
#define NODE_ACCOUNT_SETTINGS "settings"

#define FILE_FRIENDS_DATA "friends.xml"

#define NODE_FRIENDS_ROOT "friendsList"

#define FILE_INBOX_DATA "/messages_inbox.xml"

#define FILE_OUTBOX_DATA "/messages_outbox.xml"

#define NODE_MESSAGES_ROOT "messageList"

#define FILE_DRAFTS_DATA "/drafts.xml"

/*
 * class for account information storage.
 */
class Account: public QObject
{
    Q_OBJECT

private:
    FriendList friends; // list of loaded friends.
    AlbumList albums; // list of my albums.
    MessageList inboxMessages; // list of inbox messages.
    MessageList outboxMessages; // list of outbox messages.
    MessageList draftMessages; // list of drafts of messages.
    QString settings; // account settings. Uses in driver.
    QString oldSettings; // old account settings. Used if user didn't work with application

    // user account data
    Friend profile;

    // true if first request is success, otherwise false
    bool isLibraryInit;

public:
    Account(QString libraryName);
    Account(QString libraryName, QString accountId);
    ~Account();

    QTransport *transport; // interface of used driver.

    bool ready() const; // check status of Account

    void saveAccount(); // store account settings.
    static Account* loadAccount(const QString& accountId); // load account from storage.

    // get friend list or load it from cache file.
    FriendList getFriendList();

    // set friend list and store it to cache file.
    void setFriendList(const FriendList& list);

    QString accountId() const;

    QString serviceName() const;

    /**
     * @brief get list of my albums or load it from cache
     *
     * @return AlbumList list of my albums
    */
    AlbumList getAlbumList();

    /**
     * @brief set list of my albums and store it to cache file
     *
     * @param AlbumList
    */
    void setAlbumList(const AlbumList& list);

    MessageList getInboxMessageList();

    void setInboxMessageList(const MessageList&);

    MessageList getOutboxMessageList();

    void setOutboxMessageList(const MessageList&);

    void setDraftMessages(const MessageList&);

    MessageList getDraftMessages();

    Friend getProfile(const bool isNeedUpdate);

    void setProfile(const Friend& profile);

    /**
     * @brief setup proxy settings for current driver
     *
     * @param proxyHost proxy host name or QString() if proxy not use
     * @param proxyPort proxy port number or 0 if proxy not use
    */
    void setProxy(const QString& proxyHost, const int proxyPort);

    // checks that it is a first request
    bool isFirstRequest;

    // true if first request is success, otherwise false
    bool isNetworkEnabled;

private slots:
    void gotSettings(QString accountId, QString settings);
};

typedef QList<Account *> AccountList;

Q_DECLARE_METATYPE(Account *)

#endif // ACCOUNT_H
